@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2011-2017 by Andrew Mustun. All rights reserved.
+ * Copyright (c) 2011-2018 by Andrew Mustun. All rights reserved.
  * 
  * This file is part of the QCAD project.
  *
@@ -230,7 +230,7 @@ AddOn.prototype.preferenceFileExists = function() {
 
 /**
  * \return True if shortcuts can be defined for this add-on (default) or
- *      false if a add-on explicitely defines, that is does not support
+ *      false if a add-on explicitly defines, that is does not support
  *      shortcuts (ClassName.hasShortcuts()).
  */
 AddOn.prototype.hasShortcuts = function() {
@@ -444,6 +444,7 @@ AddOn.getParentAddOn = function(addOns, addOn) {
 
 /**
  * \return Array of all AddOn objects found.
+ *
  * \param dir Used internally for recursive calls
  */
 AddOn.getAddOns = function(dir) {
@@ -456,14 +457,22 @@ AddOn.getAddOns = function(dir) {
     var fileMenuList, i, k;
 
     var addOns = [];
-    var dirFilter = new QDir.Filters(QDir.NoDotAndDotDot, QDir.Readable, QDir.Dirs);
-    var sortFlags = new QDir.SortFlags(QDir.NoSort);
+    var dirFilter = makeQDirFilters(QDir.NoDotAndDotDot, QDir.Readable, QDir.Dirs);
+    var sortFlags = makeQDirSortFlags(QDir.NoSort);
     
     // first call without recursion:
     if (topCall) {
-        var args = QCoreApplication.arguments();
+        var args = RSettings.getOriginalArguments();
 
-        dir = "scripts";
+        // ignore all scripts in ./scripts directory
+        // and only load scripts from plugins
+        // used mainly for testing / development
+        if (args.contains("-ignore-script-files")) {
+            dir = undefined;
+        }
+        else {
+            dir = "scripts";
+        }
 
         // fixed set of directories that will be scanned for add-ons first to 
         // ensure fixed order of menus and tool bars:
@@ -638,14 +647,14 @@ AddOn.getAddOns = function(dir) {
 
 AddOn.getLocalAddOns = function() {
     var dataDir = new QDir(RSettings.getDataLocation());
-    var fs = new QDir.Filters(QDir.NoDotAndDotDot, QDir.Readable, QDir.Dirs, QDir.Executable);
-    var sf = new QDir.SortFlags(QDir.Name);
+    var fs = makeQDirFilters(QDir.NoDotAndDotDot, QDir.Readable, QDir.Dirs, QDir.Executable);
+    var sf = makeQDirSortFlags(QDir.Name);
     return dataDir.entryList([], fs, sf);
 };
 
 AddOn.isIgnored = function(path) {
     if (isNull(AddOn.ignores)) {
-        var args = QCoreApplication.arguments();
+        var args = RSettings.getOriginalArguments();
         AddOn.ignores = [];
         for (var i=1; i < args.length; ++i) {
             if (args[i] === "-ignore") {
