@@ -194,6 +194,31 @@ WidgetFactory.getKeyString = function(group, obj) {
     }
 };
 
+WidgetFactory.saveSize = function(widget) {
+    if (!widget) {
+        return;
+    }
+    var name = widget.objectName;
+    if (name.length===0) {
+        return;
+    }
+    RSettings.setValue(name + "/Width", widget.width);
+    RSettings.setValue(name + "/Height", widget.height);
+};
+
+WidgetFactory.restoreSize = function(widget) {
+    if (!widget) {
+        return;
+    }
+    var name = widget.objectName;
+    if (name.length===0) {
+        return;
+    }
+    var w = RSettings.getIntValue(name + "/Width", widget.width);
+    var h = RSettings.getIntValue(name + "/Height", widget.height);
+    widget.resize(w, h);
+};
+
 /**
  * Saves the current state of the given \c widget and all its child widgets.
  *
@@ -560,7 +585,7 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
                 c.setPlainText(value);
             }
             continue;
-        }        
+        }
         if (isOfType(c, RMathLineEdit)) {
             WidgetFactory.connect(c.valueChanged, signalReceiver, c.objectName);
             c.valueChanged.connect(WidgetFactory.topLevelWidget, "slotSettingChanged");
@@ -1015,7 +1040,7 @@ WidgetFactory.moveChildren = function(sourceWidget, targetWidget, settingsGroup)
 
     // move child widgets of UI file based widget directly to
     // options toolbar. rendering of tool buttons greatly depends
-    // on this (especially on Mac OS X):
+    // on this (especially on macOS):
     var children = sourceWidget.children();
     for(var i=0;i<children.length;++i) {
         var w=children[i];
@@ -1115,24 +1140,38 @@ WidgetFactory.initLineEdit = function(lineEdit, dimension) {
 
         // TODO: split into submenus (math, greek, ...):
         var symbols = [
-                ["\u00F8", qsTr("Diameter")],
-                ["\u2312", qsTr("Arc")],
-                ["\u00B0", qsTr("Degree")],
-                ["\u00B1", qsTr("Plus/Minus")],
-                ["\u2248", qsTr("Almost equal to")],
-                ["\u2243", qsTr("Asymptotically equal to")],
-                ["\u03C0", qsTr("Pi")],
-                ["\u221A", qsTr("Square root")],
-                ["\u03A6", qsTr("Phi")],
-                ["\u0278", qsTr("phi")],
-                ["\u03C6", qsTr("Alt phi")],
-                ["\u2126", qsTr("Ohm")],
-                ["\u03C9", qsTr("omega")],
-                ["\u00D7", qsTr("Multiplication")],
-                ["\u00F7", qsTr("Division")],
-                ["\u25FB", qsTr("Square")],
-                ["\u0394", qsTr("Delta")],
-                ["\\SA^B;", qsTr("Stacked text"), "\\\\SA^B;"]
+                    [0x00B0, qsTr("Degrees")],
+                    [0x00B1, qsTr("Plus/Minus")],
+                    [0x00F8, qsTr("Diameter")],
+                    [0x00F7, qsTr("Division")],
+                    [0x2248, qsTr("Almost Equal")],
+                    [0x2220, qsTr("Angle")],
+                    [0x2312, qsTr("Arc")],
+                    [0x2243, qsTr("Asymptotically Equal")],
+                    //[0xE100, qsTr("Boundary Line")],
+                    [0x2104, qsTr("Center Line")],
+                    [0x0394, qsTr("Delta")],
+                    [0x0278, qsTr("Electrical Phase")],
+                    //[0xE101, qsTr("Flow Line")],
+                    [0x2261, qsTr("Identity")],
+                    //[0xE200, qsTr("Initial Length")],
+                    //[0xE102, qsTr("Monument Line")],
+                    [0x00D7, qsTr("Multiplication")],
+                    [0x2260, qsTr("Not Equal")],
+                    [0x2126, qsTr("Ohm")],
+                    [0x03A9, qsTr("Omega")],
+                    [0x03C9, qsTr("omega")],
+                    [0x03A6, qsTr("Phi")],
+                    [0x0278, qsTr("phi")],
+                    [0x03C6, qsTr("Alt phi")],
+                    [0x03C0, qsTr("Pi")],
+                    [0x214A, qsTr("Property Line")],
+                    [0x2082, qsTr("Subscript 2")],
+                    [0x221A, qsTr("Square Root")],
+                    [0x25FB, qsTr("Square")],
+                    [0x00B2, qsTr("Squared")],
+                    [0x00B3, qsTr("Cubed")],
+                    ["\\SA^B;", qsTr("Stacked text"), "\\\\SA^B;"]
         ];
 
         if (dimension===true) {
@@ -1148,14 +1187,28 @@ WidgetFactory.initLineEdit = function(lineEdit, dimension) {
                 continue;
             }
 
-            var symbolSelf = symbol[0];
+            var symbolCode = symbol[0];
+            var symbolCodeStr;
+            var symbolSelf;
+            if (isNumber(symbolCode)) {
+                symbolCodeStr = symbolCode.toString(16);
+                while (symbolCodeStr.length<4) {
+                    symbolCodeStr = "0" + symbolCodeStr;
+                }
+                symbolCodeStr = ", \\U+" + symbolCodeStr;
+                symbolSelf = String.fromCharCode(symbolCode);
+            }
+            else {
+                symbolCodeStr = "";
+                symbolSelf = symbolCode;
+            }
             var symbolText = symbol[1];
-            var insertion = symbol[0];
+            var insertion = String.fromCharCode(symbol[0]);
             if (symbol.length===3) {
                 insertion = symbol[2];
             }
 
-            var action = subMenu.addAction(symbolSelf + "\t(" + symbolText + ")");
+            var action = subMenu.addAction(symbolSelf + "\t(" + symbolText + symbolCodeStr + ")");
             eval("action.triggered.connect(function() { lineEdit.setFocus(Qt.OtherFocusReason); lineEdit.insert(\"" + insertion + "\"); });");
         }
 
@@ -1290,6 +1343,88 @@ WidgetFactory.initVAlignCombo = function(comboBox) {
     comboBox.addItem(qsTr("Bottom"), RS.VAlignBottom);
 };
 
+WidgetFactory.initDimlunitCombo = function(comboBox) {
+    comboBox.clear();
+    comboBox.addItem(qsTr("Scientific"), RS.Scientific);
+    comboBox.addItem(qsTr("Decimal"), RS.Decimal);
+    comboBox.addItem(qsTr("Engineering"), RS.Engineering);
+    comboBox.addItem(qsTr("Architectural"), RS.ArchitecturalStacked);
+    comboBox.addItem(qsTr("Fractional"), RS.FractionalStacked);
+};
+
+WidgetFactory.initDimtadCombo = function(comboBox) {
+    comboBox.clear();
+    comboBox.addItem(qsTr("Centered"), 0);
+    comboBox.addItem(qsTr("Above"), 1);
+};
+
+WidgetFactory.initDimdsepCombo = function(comboBox) {
+    comboBox.clear();
+    comboBox.addItem(".", '.');
+    comboBox.addItem(",", ',');
+};
+
+WidgetFactory.initDimzinCombo = function(comboBox) {
+    comboBox.clear();
+    //comboBox.addItem(qsTr("Suppress 0'0\" (unsupported)"), 0);
+    comboBox.addItem(qsTr("Show trailing zeroes"), 0);
+    comboBox.addItem(qsTr("Include 0'0\"") + " " + qsTr("(unsupported)"), 1);
+    comboBox.addItem(qsTr("Include 0', suppress 0\"") + " " + qsTr("(unsupported)"), 2);
+    comboBox.addItem(qsTr("Include 0\", suppress 0'") + " " + qsTr("(unsupported)"), 3);
+    comboBox.addItem(qsTr("Suppress leading zeroes") + " " + qsTr("(unsupported)"), 4);
+    comboBox.addItem(qsTr("Suppress trailing zeroes"), 8);
+    comboBox.addItem(qsTr("Suppress leading / trailing zeroes") + " " + qsTr("(unsupported)"), 12);
+
+//    comboBox.addItem(qsTr("Suppress 0'0\""), 0);
+//    comboBox.addItem(qsTr("Include 0'0\""), 1);
+//    comboBox.addItem(qsTr("Include 0', suppress 0\""), 2);
+//    comboBox.addItem(qsTr("Include 0\", suppress 0'"), 3);
+};
+
+WidgetFactory.initDimdecCombo = function(comboBox) {
+    comboBox.clear();
+    comboBox.addItem("0", 0);
+    comboBox.addItem("1", 1);
+    comboBox.addItem("2", 2);
+    comboBox.addItem("3", 3);
+    comboBox.addItem("4", 4);
+    comboBox.addItem("5", 5);
+    comboBox.addItem("6", 6);
+    comboBox.addItem("7", 7);
+    comboBox.addItem("8", 8);
+
+};
+WidgetFactory.initDimaunitCombo = function(comboBox) {
+    comboBox.clear();
+    comboBox.addItem(qsTr("Decimal Degrees"), RS.DegreesDecimal);
+    comboBox.addItem(qsTr("Deg/min/sec"), RS.DegreesMinutesSeconds);
+    comboBox.addItem(qsTr("Gradians"), RS.Gradians);
+    comboBox.addItem(qsTr("Radians"), RS.Radians);
+    comboBox.addItem(qsTr("Surveyor's units"), RS.Surveyors);
+};
+
+WidgetFactory.initDimazinCombo = function(comboBox) {
+    comboBox.clear();
+    comboBox.addItem(qsTr("Show trailing zeroes"), 0);
+    comboBox.addItem(qsTr("Suppress leading zeroes") + " " + qsTr("(unsupported)"), 1);
+    comboBox.addItem(qsTr("Suppress trailing zeroes"), 2);
+    comboBox.addItem(qsTr("Suppress leading / trailing zeroes") + " " + qsTr("(unsupported)"), 3);
+};
+
+WidgetFactory.initDimadecCombo = function(comboBox) {
+    comboBox.clear();
+    comboBox.addItem("0", 0);
+    comboBox.addItem("1", 1);
+    comboBox.addItem("2", 2);
+    comboBox.addItem("3", 3);
+    comboBox.addItem("4", 4);
+    comboBox.addItem("5", 5);
+    comboBox.addItem("6", 6);
+    comboBox.addItem("7", 7);
+    comboBox.addItem("8", 8);
+};
+
+
 WidgetFactory.initOrientationCombo = function(comboBox) {
     comboBox.clear();
 
